@@ -1,19 +1,17 @@
 /* Copyright (C) 2005 The cairomm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <cairomm/pattern.h>
@@ -65,18 +63,6 @@ void Pattern::get_matrix(Matrix& matrix) const
   check_object_status_and_throw_exception(*this);
 }
 
-void Pattern::set_matrix(const cairo_matrix_t& matrix)
-{
-  cairo_pattern_set_matrix(m_cobject, (cairo_matrix_t*)&matrix);
-  check_object_status_and_throw_exception(*this);
-}
-
-void Pattern::get_matrix(cairo_matrix_t& matrix) const
-{
-  cairo_pattern_get_matrix(m_cobject, (cairo_matrix_t*)&matrix);
-  check_object_status_and_throw_exception(*this);
-}
-
 Matrix Pattern::get_matrix() const
 {
   Cairo::Matrix m;
@@ -85,11 +71,11 @@ Matrix Pattern::get_matrix() const
   return m;
 }
 
-PatternType Pattern::get_type() const
+Pattern::Type Pattern::get_type() const
 {
   auto pattern_type = cairo_pattern_get_type(m_cobject);
   check_object_status_and_throw_exception(*this);
-  return static_cast<PatternType>(pattern_type);
+  return static_cast<Type>(pattern_type);
 }
 
 void Pattern::set_extend(Extend extend)
@@ -98,7 +84,7 @@ void Pattern::set_extend(Extend extend)
   check_object_status_and_throw_exception(*this);
 }
 
-Extend Pattern::get_extend() const
+Pattern::Extend Pattern::get_extend() const
 {
   const auto result = static_cast<Extend>(cairo_pattern_get_extend(m_cobject));
   check_object_status_and_throw_exception(*this);
@@ -126,14 +112,14 @@ RefPtr<SolidPattern> SolidPattern::create_rgb(double red, double green, double b
 {
   auto cobject = cairo_pattern_create_rgb(red, green, blue);
   check_status_and_throw_exception(cairo_pattern_status(cobject)); 
-  return RefPtr<SolidPattern>(new SolidPattern(cobject, true /* has reference */));
+  return make_refptr_for_instance<SolidPattern>(new SolidPattern(cobject, true /* has reference */));
 }
 
 RefPtr<SolidPattern> SolidPattern::create_rgba(double red, double green, double blue, double alpha)
 {
   cairo_pattern_t* cobject  = cairo_pattern_create_rgba(red, green, blue, alpha);
   check_status_and_throw_exception(cairo_pattern_status(cobject));
-  return RefPtr<SolidPattern>(new SolidPattern(cobject, true /* has reference */));
+  return make_refptr_for_instance<SolidPattern>(new SolidPattern(cobject, true /* has reference */));
 }
 
 
@@ -150,7 +136,7 @@ SurfacePattern::get_surface()
   // we can ignore the return value since we know this is a surface pattern
   cairo_pattern_get_surface(const_cast<cairo_pattern_t*>(m_cobject), &surface);
   check_object_status_and_throw_exception(*this);
-  return RefPtr<Surface>(new Surface(surface, false /* does not have reference */));
+  return make_refptr_for_instance<Surface>(new Surface(surface, false /* does not have reference */));
 }
 
 RefPtr<const Surface>
@@ -161,7 +147,7 @@ SurfacePattern::get_surface() const
 
 RefPtr<SurfacePattern> SurfacePattern::create(const RefPtr<Surface>& surface)
 {
-  return RefPtr<SurfacePattern>(new SurfacePattern(surface));
+  return make_refptr_for_instance<SurfacePattern>(new SurfacePattern(surface));
 }
 
 SurfacePattern::SurfacePattern(cairo_pattern_t* cobject, bool has_reference)
@@ -173,25 +159,13 @@ SurfacePattern::~SurfacePattern()
 {
 }
 
-#ifndef CAIROMM_DISABLE_DEPRECATED
-void SurfacePattern::set_extend(Extend extend)
-{
-  Pattern::set_extend(extend);
-}
-
-Extend SurfacePattern::get_extend() const
-{
-  return Pattern::get_extend();
-}
-#endif //CAIROMM_DISABLE_DEPRECATED
-
 void SurfacePattern::set_filter(Filter filter)
 {
   cairo_pattern_set_filter(m_cobject, (cairo_filter_t)filter);
   check_object_status_and_throw_exception(*this);
 }
 
-Filter SurfacePattern::get_filter() const
+SurfacePattern::Filter SurfacePattern::get_filter() const
 {
   auto result = static_cast<Filter>(cairo_pattern_get_filter(m_cobject));
   check_object_status_and_throw_exception(*this);
@@ -266,7 +240,7 @@ LinearGradient::get_linear_points(double &x0, double &y0,
 
 RefPtr<LinearGradient> LinearGradient::create(double x0, double y0, double x1, double y1)
 {
-  return RefPtr<LinearGradient>(new LinearGradient(x0, y0, x1, y1));
+  return make_refptr_for_instance<LinearGradient>(new LinearGradient(x0, y0, x1, y1));
 }
 
 LinearGradient::LinearGradient(cairo_pattern_t* cobject, bool has_reference)
@@ -299,7 +273,7 @@ RadialGradient::get_radial_circles(double& x0, double& y0, double& r0,
 
 RefPtr<RadialGradient> RadialGradient::create(double cx0, double cy0, double radius0, double cx1, double cy1, double radius1)
 {
-  return RefPtr<RadialGradient>(new RadialGradient(cx0, cy0, radius0, cx1, cy1, radius1));
+  return make_refptr_for_instance<RadialGradient>(new RadialGradient(cx0, cy0, radius0, cx1, cy1, radius1));
 }
 
 RadialGradient::RadialGradient(cairo_pattern_t* cobject, bool has_reference)
